==> sphere_connector-0.4.30.tar.gz: sphere_connector-0.4.30/sphere_connector/config.py <==
"""
The MIT License (MIT)
Copyright (c) 2014-2015 University of Bristol

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
OR OTHER DEALINGS IN THE SOFTWARE.
"""
from dateutil.parser import parse as parse_datetime
from datetime import datetime, timedelta
import pytz
import logging
import simplejson as json
import os
from utils import Printable


class AnnotationConfig(Printable):
    def __init__(self, filename, offset=timedelta(0)):
        self.filename = filename
        if not offset:
            self.offset = timedelta(0)
        elif type(offset) is timedelta:
            self.offset = offset
        else:
            try:
                self.offset = timedelta(seconds=float(offset))
            except TypeError as e:
                logging.warn(e.message)
                self.offset = timedelta(0)


class ExperimentConfig(Printable):
    def __init__(self, experiment_start=datetime.now(), experiment_end=datetime.now(),
                 input_path='', output_path='', annotations=None, experiment_id=''):
        if experiment_id:
            self.experiment_id = experiment_id
        else:
            # Construct id based on unix epoch timestamps
            epoch = datetime.utcfromtimestamp(0).replace(tzinfo=pytz.utc)
            start = int((experiment_start - epoch).total_seconds() * 1000.0)
            end = int((experiment_end - epoch).total_seconds() * 1000.0)
            # self.experiment_id = experiment_start.strftime('%Y-%m-%d_0')
            self.experiment_id = "%d-%d" % (start, end)
        self.experiment_start = experiment_start if type(experiment_start) is datetime \
            else parse_datetime(experiment_start)
        self.experiment_end = experiment_end if type(experiment_end) is datetime \
            else parse_datetime(experiment_end)
        # self.offset = offset
        self.input_path = input_path
        self.output_path = output_path
        self.annotations = dict((k, AnnotationConfig(**v)) for k, v in annotations.items())

    @property
    def annotators(self):
        return ", ".join(self.annotations) if self.annotations else ""

    @property
    def annotation_files(self):
        return ", ".join(os.path.join(self.input_path, a.filename)
                         for a in self.annotations.values()) if self.annotations else ""

    @property
    def offsets(self):
        return ", ".join([a.offset for a in self.annotations]) if self.annotations else ""


class RedCapConfig(Printable):
    def __init__(self, host, proxies, token, mysql, projects, ssh=None):
        self.host = host
        self.proxies = proxies
        self.token = token
        self.ssh = ssh
        self.mysql = mysql
        self.projects = projects


class Config(Printable):
    def __init__(self, include_mongo=True, include_experiments=True, include_redcap=True):
        self.mongo = None
        self.experiments = []
        self.redcap = None
        self.annotation_path = ''
        self.output_path = ''
        self.process = {}
        self.process_on_startup = False

        try:
            with open('config.json', 'r') as f:
                logging.info('Reading ' + os.path.abspath(f.name))
                config = json.load(f)

                if include_mongo:
                    self.mongo = config['mongo']

                if include_experiments:
                    self.experiments = [ExperimentConfig(**c) for c in config['experiments']]

                if include_redcap:
                    self.redcap = RedCapConfig(**config['redcap'])

                self.annotation_path = config['annotation_path']
                self.output_path = config['output_path']
                self.process = config['process']
                self.process_on_startup = config['process_on_startup']

        except (OSError, IOError, TypeError) as e:
            # raise
            logging.error(e)

==> sphere_connector-0.5.4.tar.gz: sphere_connector-0.5.4/sphere_connector/config.py <==
"""
The MIT License (MIT)
Copyright (c) 2014-2015 University of Bristol

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
OR OTHER DEALINGS IN THE SOFTWARE.
"""
from dateutil.parser import parse as parse_datetime
from datetime import datetime, timedelta
import pytz
import logging
import simplejson as json
import os
from utils import Printable


class AnnotationConfig(Printable):
    def __init__(self, filename, offset=timedelta(0)):
        self.filename = filename
        if not offset:
            self.offset = timedelta(0)
        elif type(offset) is timedelta:
            self.offset = offset
        else:
            try:
                self.offset = timedelta(seconds=float(offset))
            except TypeError as e:
                logging.warn(e.message)
                self.offset = timedelta(0)


class ExperimentConfig(Printable):
    def __init__(self, experiment_start=datetime.now(), experiment_end=datetime.now(),
                 annotation_path='', output_path='', annotations=None, experiment_id=''):
        if experiment_id:
            self.experiment_id = str(experiment_id).zfill(3)
        else:
            # Construct id based on unix epoch timestamps
            epoch = datetime.utcfromtimestamp(0).replace(tzinfo=pytz.utc)
            start = int((experiment_start - epoch).total_seconds() * 1000.0)
            end = int((experiment_end - epoch).total_seconds() * 1000.0)
            self.experiment_id = "%d-%d" % (start, end)
            # self.experiment_id = experiment_start.strftime('%Y-%m-%d')
        self.experiment_start = experiment_start if type(experiment_start) is datetime \
            else parse_datetime(experiment_start)
        self.experiment_end = experiment_end if type(experiment_end) is datetime \
            else parse_datetime(experiment_end)
        # self.offset = offset
        self.annotation_path = annotation_path
        self.output_path = output_path
        self.annotations = dict((k, AnnotationConfig(**v)) for k, v in annotations.items())

    @property
    def annotators(self):
        return ", ".join(sorted(self.annotations.keys())) if self.annotations else ""

    @property
    def annotation_files(self):
        return ", ".join(a.filename for a in self.annotations.values()) if self.annotations else ""
        # return ", ".join(os.path.join(self.annotation_path, a.filename) if self.annotation_path else a.filename
        #                  for a in self.annotations.values()) if self.annotations else ""

    @property
    def offsets(self):
        return ", ".join([str(a.offset) for a in self.annotations.values()]) if self.annotations else ""


class RedCapConfig(Printable):
    def __init__(self, host, proxies, token, mysql, projects, ssh=None):
        self.host = host
        self.proxies = proxies
        self.token = token
        self.ssh = ssh
        self.mysql = mysql
        self.projects = projects


class BasicConfig(Printable):
    def __init__(self, include_mongo=True, include_redcap=True):
        self.mongo = None
        self.experiments = []
        self.redcap = None
        self.annotation_path = ''
        self.output_path = ''
        self.process = {}
        self.process_on_startup = False

        try:
            with open('config.json', 'r') as f:
                logging.info('Reading ' + os.path.abspath(f.name))
                config = json.load(f)

                if include_mongo:
                    self.mongo = config['mongo']

                if include_redcap:
                    self.redcap = RedCapConfig(**config['redcap'])

                self.annotation_path = config['annotation_path']
                self.output_path = config['output_path']
                self.process = config['process']
                self.process_on_startup = config['process_on_startup']

        except (OSError, IOError, TypeError) as e:
            # raise
            logging.error(e)
